@@ -1,37 +1,38 @@
-from typing import List
-import os
 import configparser
+import os
 from pathlib import Path
+from typing import List
 
 
 class ConfigFiles:
     root_folder = os.getcwd()
     apps_folder = Path(__file__).parent.resolve()
     base_config_parser = configparser.ConfigParser()
-    settings_name = "autotest"
+    settings_name = "bfet"
     settings_file = "setup.cfg"
     default_file_namig = "test_*"
     default_class_naming = "Test*"
     default_function_namig = "test_*"
+
     default_files_to_include = "forms,views,managers,models,urls,admin"
     default_files_to_exclude = ""
 
     def __init__(self) -> None:
-        self.base_config_parser.read(self.settings_file)
-        self.config_parser = self.base_config_parser[self.settings_name]
-        self.files_to_include = self.get_files_to(
-            "include", self.default_files_to_include
-        )
-        self.file_namig = self.config_parser.get("file_namig", self.default_file_namig)
-        self.class_naming = self.config_parser.get(
-            "class_naming", self.default_class_naming
-        )
-        self.function_namig = self.config_parser.get(
-            "function_namig", self.default_function_namig
-        )
-        self.files_to_exclude = self.get_files_to(
-            "exclude", self.default_files_to_exclude
-        )
+        try:
+            self.base_config_parser.read(self.settings_file)
+            self.config_parser = self.base_config_parser[self.settings_name]
+        except KeyError:
+            # TODO raise and exception or advice the user to create or allow the automatic creation
+            # of the setup.cfg settings for bfet
+            return
+        else:
+            self.files_to_include = self.get_files_to("include", self.default_files_to_include)
+            self.file_namig = self.config_parser.get("file_namig", self.default_file_namig)
+            self.class_naming = self.config_parser.get("class_naming", self.default_class_naming)
+            self.function_namig = self.config_parser.get(
+                "function_namig", self.default_function_namig
+            )
+            self.files_to_exclude = self.get_files_to("exclude", self.default_files_to_exclude)
 
     def get_files_to(self, what_to_do: str, default: str) -> List:
         files_to = self.config_parser.get(what_to_do, default)
